/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "ReadOnlyEditorController.h"
#import "NonCascadingWindow.h"


@implementation ReadOnlyEditorController

+ (void) showWindowWith: (NSString*) stringContent title:(NSString*)titleString
{
	ReadOnlyEditorController* controller = [[[ReadOnlyEditorController alloc] initWithContent:stringContent title:titleString] autorelease];
	
	[controller showWindow:self];
	
	//[[controller window] makeKeyWindow];
}

- (id) initWithContent:(NSString*)stringContent title:(NSString*)titleString
{
    self = [super initWithWindowNibName:@"ReadOnlyEditor"];
    
	// self autorelease when window closes
	[self retain];
	
	fStringContent = [stringContent retain];
	fTitleString   = [titleString retain];
	
    return self;
}

- (void) dealloc
{
	[fStringContent release];
	[fTitleString release];
	
	[super dealloc];
}

- (void) windowDidLoad
{
	// Make the window scrollable in both horiz and vert directions
	// thereby turning off text wrap
	NSTextContainer* textContainer = [fTextView textContainer];
	NSView* clipView = [fTextView superview];
	NSScrollView* scrollView = (NSScrollView*) [clipView superview];

    [scrollView setHasVerticalScroller:YES];
    [scrollView setHasHorizontalScroller:YES];

	[textContainer setContainerSize:NSMakeSize(1.0e7 /*BIG number*/, 1.0e7 /*BIG number*/)];
    [textContainer setWidthTracksTextView:NO];
    [textContainer setHeightTracksTextView:NO];

    [fTextView setMaxSize:NSMakeSize(1.0e7 /*BIG number*/, 1.0e7 /*BIG number*/)];
    [fTextView setHorizontallyResizable:YES];
    [fTextView setVerticallyResizable:YES];

	[fTextView setString:fStringContent];
	
	NonCascadingWindow* window = (NonCascadingWindow*) [self window];
	
	[window setTitle:fTitleString];

	[window setDefaultsFrameName:@"ReadOnlyDialogFrameSize"];
}


- (IBAction) closeButton: (id) sender
{
	[self close];
}

- (void)windowWillClose:(NSNotification *)aNotification
{
	[self autorelease];
}


@end
